aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/gpu/GrStyle.h
diff options
context:
space:
mode:
authorGravatar bsalomon <bsalomon@google.com>2016-05-04 13:50:29 -0700
committerGravatar Commit bot <commit-bot@chromium.org>2016-05-04 13:50:29 -0700
commit06077565b18714ff3fc0db9118e2c21f6f25243f (patch)
treeb5b250ce3600dc4fd67ebea5d7096ec1779bc133 /src/gpu/GrStyle.h
parent345242671587d7273819bfe423be96e4392033e3 (diff)
Make cap only affect the keys of GrShapes that are possibly-open
Diffstat (limited to 'src/gpu/GrStyle.h')
-rw-r--r--src/gpu/GrStyle.h19
1 files changed, 14 insertions, 5 deletions
diff --git a/src/gpu/GrStyle.h b/src/gpu/GrStyle.h
index d63df32290..c65b22b81a 100644
--- a/src/gpu/GrStyle.h
+++ b/src/gpu/GrStyle.h
@@ -49,21 +49,30 @@ public:
};
/**
+ * Optional flags for computing keys that may remove unnecessary variation in the key due to
+ * style settings that don't affect particular classes of geometry.
+ */
+ enum KeyFlags {
+ // The shape being styled has no open contours.
+ kClosed_KeyFlag = 0x1
+ };
+
+ /**
* Computes the key length for a GrStyle. The return will be negative if it cannot be turned
* into a key. This occurs when there is a path effect that is not a dash. The key can
* either reflect just the path effect (if one) or the path effect and the strokerec. Note
* that a simple fill has a zero sized key.
*/
- static int KeySize(const GrStyle& , Apply);
+ static int KeySize(const GrStyle& , Apply, uint32_t flags = 0);
/**
* Writes a unique key for the style into the provided buffer. This function assumes the buffer
* has room for at least KeySize() values. It assumes that KeySize() returns a non-negative
* value for the style and Apply param. This is written so that the key for just dash
* application followed by the key for the remaining SkStrokeRec is the same as the key for
* applying dashing and SkStrokeRec all at once.
*/
- static void WriteKey(uint32_t*, const GrStyle&, Apply);
+ static void WriteKey(uint32_t*, const GrStyle&, Apply, uint32_t flags = 0);
GrStyle() : GrStyle(SkStrokeRec::kFill_InitStyle) {}
@@ -49,21 +49,30 @@ public:
* Writes a unique key for the style into the provided buffer. This function assumes the buffer
* has room for at least KeySize() values. It assumes that KeySize() returns a non-negative
- * value for the style and Apply param. This is written so that the key for just dash
- * application followed by the key for the remaining SkStrokeRec is the same as the key for
- * applying dashing and SkStrokeRec all at once.
+ * value for the combination of GrStyle, Apply and flags params. This is written so that the key
+ * for just dash application followed by the key for the remaining SkStrokeRec is the same as
+ * the key for applying dashing and SkStrokeRec all at once.
*/